%Generates x,y data to test out numeric calculus methods
% LAST UPDATED by Andy French Dec 2021.
function xygen_test

%Number of data points
N = 10;

%Fontsize
fsize = 18;

%Generate test x,y data
[x,y,I] = xygen(0,10,N);

%Generate finer sample for curve underlay
[xx,yy,II] = xygen(0,10,1000);

%Plot graph
figure('color',[1 1 1],'name','xygen_test')
plot( xx, yy, '-b','linewidth',2); hold on;
plot(x,y,'r+','markersize',12);
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)
title('Test data (x,y)','fontsize',fsize)
set(gca,'fontsize',fsize); grid on;
print( gcf,'test xy data.png','-dpng','-r300' ); close(gcf);

%Save x,y data into a.mat file
save 'test xy data' 'x' 'y' 'I'

%%

%xygen
% Function which generates some x,y data for use in numeric integration
% functions. N points are returned on interval [a,b].
%
% LAST UPDATED by Andy French Jan 2017.

function [x,y,I] = xygen(a,b,N)

%Generate a vector of x data
x = linspace(a,b,N);

%Generate a vector of y data
y = sin( 2*2*pi*x/10 ) - 3*exp(-x) + 3;

%Evaluate definite integral between limits a and b
I = -(10/(2*2*pi))*cos( 2*2*pi*b/10) + 3*exp(-b) + 3*b - ...
    ( -(10/(2*2*pi))*cos( 2*2*pi*a/10) + 3*exp(-a) + 3*a );

%End of code